@@ -17,7 +17,10 @@
 
 /**/
 
+#include "MainWin.h"
+
 #include "HeadLine.h"
+#include "Url.h"
 #include "Message.h"
 #include "Misc.h"
 
@@ -26,3 +29,7 @@
 
 /**/
 
+#define CONFIG_FILE_NAME	".nnhl.cnf"
+
+/**/
+
