@@ -15,6 +15,11 @@
 #include <WSCcomboBox.h>
 #include <WSCvbtn.h>
 #include <WSCvlabel.h>
+#include <WSCmenuArea.h>
+#include <WSCpulldownMenu.h>
+#include <WSCdialog.h>
+#include <WSCvifield.h>
+#include <WSCvtoggle.h>
 
 //--- OBJECT instance variable ---//
 extern WSCmainWindow* MainWin;
@@ -22,18 +27,33 @@ extern WSCvkslabel* Maivksl_HeadLine;
 extern WSCvtimer* Maivtim_MainTimer;
 extern WSCvtimer* Maivtim_BeginTimer;
 extern WSCvscrBar* Maivscr_ScrollBar;
-extern WSCcomboBox* Maicomb_Url;
+extern WSCcomboBox* Maicomb_NameList;
 extern WSCvbtn* Maivbtn_StopBtn;
 extern WSCvbtn* Maivbtn_NextUrlBtn;
 extern WSCvbtn* Maivbtn_PrevUrlBtn;
 extern WSCvbtn* Maivbtn_NextArtBtn;
 extern WSCvbtn* Maivbtn_PrevArtBtn;
-extern WSCvlabel* Maivlab_Article;
+extern WSCvlabel* Maivlab_Art;
 extern WSCvlabel* Maivlab_Thr;
 extern WSCvbtn* Maivbtn_NextThrBtn;
 extern WSCvbtn* Maivbtn_PrevThrBtn;
 extern WSCvlabel* Maivlab_Site;
 extern WSCvbtn* Maivbtn_BarBtn;
 extern WSCvtimer* Maivtim_UpdateTimer;
+extern WSCmenuArea* Maimenu_000;
+extern WSCpulldownMenu* Maipull_MainMenuFile;
+extern WSCpulldownMenu* Maipull_MainMenuOpt;
+extern WSCdialog* Cnfdial_ConfigUrl;
+extern WSCvbtn* Cnfvbtn_NewBtn;
+extern WSCvbtn* Cnfvbtn_UpdateBtn;
+extern WSCvifield* Cnfvifi_Name;
+extern WSCvifield* Cnfvifi_Url;
+extern WSCvlabel* Cnfvlab_Name;
+extern WSCvlabel* Cnfvlab_Url;
+extern WSCvtoggle* Cnfvtog_Download;
+extern WSCvbtn* Cnfvbtn_DeleteBtn;
+extern WSCcomboBox* Cnfcomb_NameList;
+extern WSCcomboBox* Cnfcomb_Encoding;
+extern WSCvlabel* Cnfvlab_Encoding;
 
 #endif /* _MainWin_H */
