@@ -5,9 +5,25 @@
 #include <WSCfunctionList.h>
 #include <WSCbase.h>
 
+#include "Mes.h"
+
+/**/
+
+typedef enum {
+	LANG_KIND_ENGLISH,
+	LANG_KIND_JAPANESE,
+	LANG_KIND_MAX_N,
+} ELangKind;
+
+/**/
+
+void ResetMessage( ELangKind nLang );
+
 void PopupError( WSCstring str );
 void PopupWarning( WSCstring str );
 void PopupMessage( WSCstring str );
-void PopupMsgCommon( WSCstring strMsgType, WSCstring str );
+void PopupMesCommon( WSCstring strMesType, WSCstring str );
+
+/**/
 
 #endif /* MESSAGE_H */
