@@ -11,6 +11,22 @@
 
 /**/
 
+#ifdef _WIN32
+
+static void *(*gNewsFunc)( void * ) = NULL;
+
+DWORD WINAPI NewsThread( void *arg )
+{
+	if( gNewsFunc != NULL )
+		gNewsFunc( NULL );
+
+	return 0;
+}
+
+#endif /* _WIN32 */
+
+/**/
+
 bool NewsThreadCreate( void *(*func)( void * ) )
 {
 #ifdef _WIN32
@@ -21,8 +37,10 @@ bool NewsThreadCreate( void *(*func)( void * ) )
 		return false;
 # else
 	DWORD id = 0;
-	HANDLE status = CreateThread( NULL, 0, (DWORD (*)( void * ))func,
-		(void *)NULL, 0, &id );
+	gNewsFunc = func;
+	HANDLE status = CreateThread( NULL, 0,
+		NewsThread,
+		NULL, 0, &id );
 	if( status == FALSE )
 		return false;
 # endif
