@@ -10,7 +10,7 @@ WS_WINMAIN
 #endif
 
 char* mou[] = {
-" 0     132        0          black      white",
+WS_DEFAULT_MOUSE_ID,
 NULL};
 
 void _mouse_init_(){
@@ -18,8 +18,8 @@ void _mouse_init_(){
 }
 
 char* fon[] = {
-"20,0,0,0,400,0,0,0,0,3,2,1,49,?l?r ?S?V?b?N",
-"14,0,0,0,400,0,0,0,0,3,2,1,49,?l?r ?S?V?b?N",
+"14 iso8859 * * * r * ",
+"14 iso8859 * * * r * ",
 "18 iso8859 * * * r *",
 "20 iso8859 * * * r *",
 "22 iso8859 * * * r *",
@@ -36,7 +36,7 @@ class _init_app_class_{
     WSGFdeviceInitialize();
     WSGIappDev()->setInitHandler(_font_init_);
     WSGIappDev()->setInitHandler(_mouse_init_);
-    WSGIappLocaleSet()->setDefaultEncoding(21);
+    WSGIappLocaleSet()->setDefaultEncoding(20);
     WSDappDev* app = WSGIappDev();
     app->setInstanceName("nnhl");
   };
@@ -44,10 +44,10 @@ class _init_app_class_{
 static _init_app_class_ _execute_app_class_;
 
 //--- OBJECT execute auto initialize ---//
-extern WSDLEX void _create_win_MainWin();
+extern WSDLEX WSCbase* _create_win_MainWin();
 class _initialize_window_0{
  public: _initialize_window_0(){
-  WSGIappDev()->setInitHandler(_create_win_MainWin);
+  WSGIappDev()->setInitHandler((void(*)())_create_win_MainWin);
  };
 };
 static _initialize_window_0 _execute_initialize_0;
