@@ -10,7 +10,7 @@ WS_WINMAIN
 #endif
 
 char* mou[] = {
-"0   IDC_ARROW",
+WS_DEFAULT_MOUSE_ID,
 NULL};
 
 void _mouse_init_(){
@@ -44,10 +44,10 @@ class _init_app_class_{
 static _init_app_class_ _execute_app_class_;
 
 //--- OBJECT execute auto initialize ---//
-extern WSDLEX void _create_win_MainWin();
+extern WSDLEX WSCbase* _create_win_MainWin();
 class _initialize_window_0{
  public: _initialize_window_0(){
-  WSGIappDev()->setInitHandler(_create_win_MainWin);
+  WSGIappDev()->setInitHandler((void(*)())_create_win_MainWin);
  };
 };
 static _initialize_window_0 _execute_initialize_0;
